@@ -79,7 +79,7 @@ class ContextJson(object):
         json_value.context=self.context
         json_value.item=item
         try:
-            self.context.getValue(item+"!=None")
+            self.context.getValue(item+"!=null")
         except ValueError:
             raise NameError(item) from None
         return json_value
